Struct Dec

pub struct Dec(pub I256);
A 256 bit number with POS_DECIMAL_PRECISION number of Dec places.

To be precise, an instance X of this type should be interpreted as the Dec X * 10 ^ (-POS_DECIMAL_PRECISION)

Tuple Fields

0: I256

Implementations

Source

impl Dec

pub fn trunc_div(&self, rhs: &Dec) -> Option<Dec>

Performs division with truncation.

This method divides self by rhs (right-hand side) and truncates the result to POS_DECIMAL_PRECISION decimal places. Truncation here means that any fractional part of the result that exceeds POS_DECIMAL_PRECISION is discarded.

Breakdown of the algorithm

The division is performed in the following way:

  1. The absolute values of the numerator and denominator are used for the division.
  2. The result is calculated to a fixed precision defined by POS_DECIMAL_PRECISION.
  3. If either the numerator or denominator (but not both) is negative, the result is negated.
  4. If the division is impossible (e.g., division by zero or overflow), None is returned.
Example
use namada_core::dec::Dec;

let x = Dec::new(3, 1).unwrap(); // Represents 0.3
let y = Dec::new(2, 1).unwrap(); // Represents 0.2
let result = x.trunc_div(&y).unwrap();
assert_eq!(result, Dec::new(15, 1).unwrap()); // Result is 1.5 truncated to 1 decimal place
Arguments
  • rhs: The right-hand side Dec value for the division.
Returns

An Option<Dec> which is Some with the result if the division is successful, or None if the division cannot be performed.

pub fn zero() -> Dec

The representation of 0

pub fn is_zero(&self) -> bool

Check if value is zero

pub fn one() -> Dec

The representation of 1

pub fn two() -> Dec

The representation of 2

pub fn one_third() -> Dec

The representation of 1 / 3

pub fn two_thirds() -> Dec

The representation of 2 / 3

pub fn two_fifths() -> Dec

The representation of 2 / 5

pub fn new(mantissa: i128, scale: u8) -> Option<Dec>

Create a new Dec using a mantissa and a scale.

pub fn abs_diff(&self, other: Dec) -> Result<Dec, Error>

Get the non-negative difference between two Decs.

pub fn abs(&self) -> Uint

Get the absolute value of self as integer

pub fn to_i256(&self) -> I256

Convert the Dec type into a I256 with truncation

pub fn to_uint(&self) -> Option<Uint>

Convert the Dec type into a Uint with truncation

pub fn checked_sub(&self, rhs: Dec) -> Option<Dec>

Do subtraction of two Decs

pub fn checked_add(&self, other: Dec) -> Option<Dec>

Do addition of two Decs

pub fn checked_mul(&self, other: impl Into<Dec>) -> Option<Dec>

Checked multiplication. Return None if overflow. This methods will overflow incorrectly if both arguments are greater than 128bit.

pub fn checked_div(self, rhs: impl Into<Dec>) -> Option<Dec>

Checked division

pub fn checked_neg(&self) -> Option<Dec>

Checked negation

pub fn is_negative(&self) -> bool

Return if the Dec is negative

pub fn ceil(&self) -> Option<I256>

Return the integer value of a Dec by rounding up.