pub struct Dec(pub I256);Expand description
A 256 bit number with POS_DECIMAL_PRECISION number of Dec places.
To be precise, an instance X of this type should be
interpreted as the Dec X * 10 ^ (-POS_DECIMAL_PRECISION)
Tuple Fields
0: I256Implementations
Sourceimpl Dec
impl Dec
Sourcepub fn trunc_div(&self, rhs: &Dec) -> Option<Dec>
pub fn trunc_div(&self, rhs: &Dec) -> Option<Dec>
Performs division with truncation.
This method divides self by rhs (right-hand side) and truncates the
result to POS_DECIMAL_PRECISION decimal places. Truncation here
means that any fractional part of the result that exceeds
POS_DECIMAL_PRECISION is discarded.
Breakdown of the algorithm
The division is performed in the following way:
- The absolute values of the numerator and denominator are used for the division.
- The result is calculated to a fixed precision defined by
POS_DECIMAL_PRECISION. - If either the numerator or denominator (but not both) is negative, the result is negated.
- If the division is impossible (e.g., division by zero or overflow),
Noneis returned.
Example
use namada_core::dec::Dec;
let x = Dec::new(3, 1).unwrap(); // Represents 0.3
let y = Dec::new(2, 1).unwrap(); // Represents 0.2
let result = x.trunc_div(&y).unwrap();
assert_eq!(result, Dec::new(15, 1).unwrap()); // Result is 1.5 truncated to 1 decimal placeArguments
rhs: The right-hand sideDecvalue for the division.
Returns
An Option<Dec> which is Some with the result if the division is
successful, or None if the division cannot be performed.
Sourcepub fn two_thirds() -> Dec
pub fn two_thirds() -> Dec
The representation of 2 / 3
Sourcepub fn two_fifths() -> Dec
pub fn two_fifths() -> Dec
The representation of 2 / 5
Sourcepub fn new(mantissa: i128, scale: u8) -> Option<Dec>
pub fn new(mantissa: i128, scale: u8) -> Option<Dec>
Create a new Dec using a mantissa and a scale.
Sourcepub fn abs_diff(&self, other: Dec) -> Result<Dec, Error>
pub fn abs_diff(&self, other: Dec) -> Result<Dec, Error>
Get the non-negative difference between two Decs.
Sourcepub fn checked_mul(&self, other: impl Into<Dec>) -> Option<Dec>
pub fn checked_mul(&self, other: impl Into<Dec>) -> Option<Dec>
Checked multiplication. Return None if overflow.
This methods will overflow incorrectly if both arguments are greater
than 128bit.
Sourcepub fn checked_neg(&self) -> Option<Dec>
pub fn checked_neg(&self) -> Option<Dec>
Checked negation
Sourcepub fn is_negative(&self) -> bool
pub fn is_negative(&self) -> bool
Return if the Dec is negative